using System;
using System.Collections;
 
class Account
{
    private decimal balance;
    private decimal interestRate;
    private string holderName;
 
    public Account(decimal initialBalance, decimal initialInterestRate, 
        string initialHolderName)
    {
        balance = initialBalance;
        interestRate = initialInterestRate;
        holderName = initialHolderName;
        BankStatistician.AccountAdded(balance);
        Console.WriteLine("New account opened! All info was supplied\n"); 
    }
     
    public Account(string initialHolderName)
    {
        balance = 0;
        interestRate = 0;
        holderName = initialHolderName;
        BankStatistician.AccountAdded(balance);
        Console.WriteLine("New account opened! Only the holder name was supplied\n"); 
    }
     
    public Account()
    {
        balance = 0;
        interestRate = 0;
        holderName = "Not assigned yet";
        BankStatistician.AccountAdded(balance);
        Console.WriteLine("New account opened! No info was supplied\n");    
    }
 
    public void SetBalance (decimal newBalance)
    {
        balance = newBalance;
    }
 
    public void SetInterestRate (decimal newInterestRate)
    {
        interestRate = newInterestRate;
    }
 
    public void PrintDetails()
    {
        Console.WriteLine("Account holder: " + holderName);
        Console.WriteLine("Balance: {0:C}", balance);
        Console.WriteLine("Interest rate: {0:C}\n", interestRate);
    }
}
 
class BankStatistician
{
    private static int accountsCreated;
    private static decimal totalOpeningBalance;
 
    public static void AccountAdded(decimal openingBalance)
    {
        accountsCreated++;
        totalOpeningBalance += openingBalance;
    }
     
    public static void PrintAccountStatistics ()
    {
        Console.WriteLine("Number of accounts created: {0}", accountsCreated);
        Console.WriteLine("Average opening balance: {0:N2}", 
            ((accountsCreated == 0) ? 0 : (totalOpeningBalance / accountsCreated)));
    }
}
 
class Bank
{
    private ArrayList accounts;
     
    public Bank()
    {
        Console.WriteLine("Congratulations! You have created a new bank");
        accounts = new ArrayList();
    }
     
    public void OpenNewAccount ()
    {
        int choice;
        decimal initialBalance;
        decimal initialInterestRate;
        string initialHolderName;
         
        Console.WriteLine("Enter the number matching the information you have now");
        Console.WriteLine("1) Balance, interest rate and name of account holder");
        Console.WriteLine("2) Only the name of the account holder");
        Console.WriteLine("3) No information available");
        choice = Convert.ToInt32(Console.ReadLine());
        switch (choice)
        {
            case 1:
                Console.Write("Enter opening balance: ");
                initialBalance = Convert.ToDecimal(Console.ReadLine());
                Console.Write("Enter initial interest rate: ");
                initialInterestRate = Convert.ToDecimal(Console.ReadLine());
                Console.Write("Enter name of account holder: ");
                initialHolderName = Console.ReadLine();
                accounts.Add(new Account(initialBalance, initialInterestRate,
                    initialHolderName));
                break;
            case 2:
                Console.Write("Enter the name of the account holder: ");
                initialHolderName = Console.ReadLine();
                accounts.Add(new Account(initialHolderName));
                break;
            case 3:
                accounts.Add(new Account());
                break;
            default:
                Console.WriteLine("Invalid input");
                break;
        }
    }
    
    public void PrintCurrentAccounts ()
    {
        foreach (Account tempAccount in accounts)
        {
            tempAccount.PrintDetails();
        }
    }
}     

class BankTester
{
    public static void Main()
    {
        string answer;
        
        Bank myBank = new Bank();
        Console.WriteLine("Would you like to open an account? Y)es N)o");
        answer = Console.ReadLine().ToUpper();
        while (!(answer == "N"))
        {       
            myBank.OpenNewAccount();
            Console.WriteLine("Would you like to open another account? Y)es N)o");
            answer = Console.ReadLine().ToUpper();
        }
        myBank.PrintCurrentAccounts();
        BankStatistician.PrintAccountStatistics();
    }
}
